==> oarepo-runtime-1.2.20.tar.gz: oarepo-runtime-1.2.20/oarepo_runtime/facets/date.py <==
from oarepo_runtime.ui.marshmallow import (
    LocalizedDate,
    LocalizedTime,
    LocalizedDateTime,
    LocalizedEDTF,
    LocalizedEDTFInterval,
)
import re
from .base import LabelledValuesTermsFacet
from invenio_search.engine import dsl
from invenio_records_resources.services.records.facets.facets import LabelledFacetMixin


class DateFacet(LabelledValuesTermsFacet):
    def value_labels(self, values):
        return {val: LocalizedDate().format_value(val) for val in values}


class TimeFacet(LabelledValuesTermsFacet):
    def value_labels(self, values):
        return {val: LocalizedTime().format_value(val) for val in values}


class DateTimeFacet(LabelledValuesTermsFacet):
    def value_labels(self, values):
        return {val: LocalizedDateTime().format_value(val) for val in values}


class EDTFFacet(LabelledValuesTermsFacet):
    def value_labels(self, values):
        return {
            val: LocalizedEDTF().format_value(convert_to_edtf(val)) for val in values
        }


class EDTFIntervalFacet(LabelledFacetMixin, dsl.DateHistogramFacet):
    # auto_date_histogram
    def __init__(self, *args, **kwargs):
        if "interval" not in kwargs:
            kwargs["interval"] = "year"
        super().__init__(*args, **kwargs)

    def value_labels(self, values):
        return {
            val: LocalizedEDTFInterval().format_value(convert_to_edtf(val))
            for val in values
        }


def convert_to_edtf(val):
    if "/" in val:
        # interval
        return "/".join(convert_to_edtf(x) for x in val.split("/"))
    val = re.sub(r"T.*", "", val)  # replace T12:00:00.000Z with nothing
    print(val)
    return val

==> oarepo-runtime-1.3.23.tar.gz: oarepo-runtime-1.3.23/oarepo_runtime/facets/date.py <==
import re

from invenio_records_resources.services.records.facets.facets import LabelledFacetMixin
from invenio_search.engine import dsl

from oarepo_runtime.ui.marshmallow import (
    LocalizedDate,
    LocalizedDateTime,
    LocalizedEDTF,
    LocalizedEDTFInterval,
    LocalizedTime,
)

from .base import LabelledValuesTermsFacet


class DateFacet(LabelledValuesTermsFacet):
    def value_labels(self, values):
        return {val: LocalizedDate().format_value(val) for val in values}


class TimeFacet(LabelledValuesTermsFacet):
    def value_labels(self, values):
        return {val: LocalizedTime().format_value(val) for val in values}


class DateTimeFacet(LabelledValuesTermsFacet):
    def value_labels(self, values):
        return {val: LocalizedDateTime().format_value(val) for val in values}


class EDTFFacet(LabelledValuesTermsFacet):
    def value_labels(self, values):
        return {
            val: LocalizedEDTF().format_value(convert_to_edtf(val)) for val in values
        }


class AutoDateHistogramFacet(dsl.DateHistogramFacet):
    agg_type = 'auto_date_histogram'
    def __init__(self, **kwargs):
        # skip DateHistogramFacet constructor
        super(dsl.DateHistogramFacet, self).__init__(**kwargs)


class EDTFIntervalFacet(LabelledFacetMixin, AutoDateHistogramFacet):
    # auto_date_histogram
    def __init__(self, *args, **kwargs):
        # if "interval" not in kwargs:
        #     kwargs["interval"] = "year"
        super().__init__(*args, **kwargs)

    def value_labels(self, values):
        return {
            val: LocalizedEDTFInterval().format_value(convert_to_edtf(val))
            for val in values
        }


class DateIntervalFacet(EDTFIntervalFacet):
    pass

def convert_to_edtf(val):
    if "/" in val:
        # interval
        return "/".join(convert_to_edtf(x) for x in val.split("/"))
    val = re.sub(r"T.*", "", val)  # replace T12:00:00.000Z with nothing
    print(val)
    return val
